@@ -13,7 +13,7 @@ def create_motorcycle_model(filename: str):
         filename=filename,
     ).motorcycle_model
 
-    print(motorcycle_model)
+    pass
 
 
 def create_all_models() -> List[MotorcycleModel]:
@@ -38,10 +38,12 @@ def create_all_models() -> List[MotorcycleModel]:
 
 
 if __name__ == "__main__":
-    create_motorcycle_model("./xlsx_lib/files/FICHA T MAX 560 2020.xlsx")
+    # create_motorcycle_model("./xlsx_lib/files/FICHA T MAX 560 2020.xlsx")
+    # create_motorcycle_model("/home/tomasdarioam/projects/infomoto/vps-backup/a1/_data/gilera/sc-125-06/FICHA  SC 125  ´06 -.xlsx")
     # create_motorcycle_model("files/FICHA MONSTER 796.xlsx")
     # create_motorcycle_model("files/FICHA PEGASO 650 ´93 ´00.xlsx")
     # create_motorcycle_model("files/FICHA XVS 950 STAR ´14.xlsx")
     # create_motorcycle_model("files/FICHA FORZA 125 ´15 .xlsx")
     # create_motorcycle_model("files/FICHA ATLANTIC 125 200 ´02.xlsx")
     # create_all_models()
+    pass
