@@ -6,7 +6,7 @@ from xlsx_lib.domain.electronic.component_attribute import ComponentAttribute
 
 
 class ElementComponent(CamelModel):
-    name: str
+    name: Optional[str]
     value: Optional[str]
     observations: Optional[str]
     attributes: Optional[List[ComponentAttribute]]
