@@ -4,6 +4,6 @@ from camel_model.camel_model import CamelModel
 
 
 class ReplacementPart(CamelModel):
-    name: str
+    name: Optional[str]
     reference: Optional[str]
     observations: Optional[str]
