@@ -1,4 +1,5 @@
-from typing import Optional, List
+from io import BytesIO
+from typing import Optional, List, Union
 
 from openpyxl import \
     Workbook, \
@@ -35,13 +36,17 @@ class MotorcycleModelWorkbook:
 
     def __init__(
             self,
-            filename: any
+            file: Union[BytesIO, str],
+            filename: Optional[str],
     ):
-        workbook: Workbook = load_workbook(filename=filename)
+        workbook: Workbook = load_workbook(filename=file)
 
-        model_name: str = filename[filename.rfind("/") + 1:filename.rfind(".")] \
-            .rstrip() \
-            .replace("FICHA ", "")
+        model_name: str
+
+        model_name = filename[filename.rfind("/") + 1:filename.rfind(".")] \
+            .replace("FICHA ", "") \
+            .strip() \
+            .replace("  ", " ")
 
         generic_replacements: Optional[List[Replacement]] = None
         electronic_elements: Optional[List[ElectronicElement]] = None
